@@ -129,7 +129,13 @@ B<Extract Variable> - C<C-o e e v> -- Do the refactoring Extract
 Variable of the active region.
 
 B<Find Callers> - C>C-o e f c> -- Find callers of a method in the
-project and insert them as a comment in the source.
+project and insert the call tree as a comment in the source.
+
+B<Visualize Callers> - C>C-o e v c> -- Visualize the callers comment
+created by "Find Callers" using GrapViz.
+
+B<Visualize Callers> - C>C-o e v c> -- Visualize callers in a call
+tree (found by Find Callers) by drawing the call tree using GraphViz.
 
 B<Edit Test Count> -- C<C-o e t c> -- Increase the test count
 (e.g. "tests => 43")
@@ -1353,7 +1359,7 @@ Nice!
 =head3 Edit -- Find Callers
 
 C<C-o e f c> -- Find callers of a method in the current project, and
-insert the package->sub as a comment.
+insert the package->sub as a call tree in a comment.
 
 This is for understanding where in the code base method calls
 originate.
@@ -1400,18 +1406,37 @@ for that method is now inserted on the line above.
 You can go on like this and add more callers to investigate the code
 structure.
 
-The cursor is placed conveniently to make it easy to subsequent
+The cursor is placed conveniently to make it easy to add subsequent
 callers to the call tree.
 
 If the same caller is already present in the comment, it is marked
 with a * to indicate that there's no point following them.
 
-The method of identifying callers works by method names alone, so
-there might be false positives, or uninteresting callers added to the
-list. Delete those lines to avoid clutter.
+Caveat: The method of identifying callers works by method names alone,
+so there might be false positives, or uninteresting callers added to
+the list. Delete those lines to avoid clutter.
 
 
 
+=head3 Edit -- Visualize Callers
+
+C<C-o e v c> -- Visualize callers in a call tree comment (collected
+using Find Callers above) by drawing it using GraphViz.
+
+Put the cursor in a comment with the call tree and hit C<C-o e v
+c>. PerlySense will create a temporary .dot file and let GraphViz
+render it into a nice .png image, which will be opened.
+
+If you're running a graphical Emacs it might even look pretty.
+
+This requires GraphViz' C<dot> binary to be installed:
+
+    sudo apt-get install graphviz  # Debian / Ubuntu
+    sudo yum install graphviz      # Redhat / CentOS
+
+on OSX, try brew something.
+
+
 =head3 Assist With -- Regex
 
 
@@ -1866,7 +1891,7 @@ use warnings;
 use utf8;
 
 package Devel::PerlySense;
-$Devel::PerlySense::VERSION = '0.0215';
+$Devel::PerlySense::VERSION = '0.0216';
 
 
 use Spiffy -Base;
@@ -1876,6 +1901,7 @@ use File::Basename;
 use File::Path;
 use File::Find::Rule;
 use Path::Class qw/dir file/;
+use Path::Tiny;
 use Pod::Text;
 use IO::String;
 use Cache::Cache;
@@ -1895,6 +1921,8 @@ use Devel::PerlySense::Class;
 use Devel::PerlySense::Document;
 use Devel::PerlySense::Document::Location;
 use Devel::PerlySense::BookmarkConfig;
+use Devel::PerlySense::CallTree;
+use Devel::PerlySense::CallTree::Graph;
 
 
 
@@ -2749,6 +2777,39 @@ sub raCallSiteForMethod {
 
 
 
+=head2 rhFileCallerVisualized(source => $source)
+
+Extract call tree from $source and render it into a .dot and .png
+file.
+
+Return hash ref with (keys: "dot", "image"; values: file names).
+
+Die if there is no "dot" binary to run.
+
+=cut
+sub rhFileCallerVisualized {
+    my ($source) = Devel::PerlySense::Util::aNamedArg(["source"], @_);
+
+    # TODO: extract
+    my $dirTemp = path("~/.PerlySense/temp");
+    my $dirTempCallTree = path($dirTemp, "call_tree");
+
+    my $treeCallers = Devel::PerlySense::CallTree->new(source => $source);
+    my $graph = Devel::PerlySense::CallTree::Graph->new({
+        call_tree  => $treeCallers,
+        output_dir => $dirTempCallTree,
+    });
+    $graph->create_graph();
+
+    return {
+        dot   => $graph->dot_file . "",
+        image => $graph->output_file . "",
+    };
+}
+
+
+
+
 =head1 IMPLEMENTATION METHODS
 
 =head2 fileFindLookingAround($fileModuleBase, $dirOrigin, $nameModule?)
